@@ -6,7 +6,7 @@ use base qw( Data::Phrasebook::Loader::Base Data::Phrasebook::Debug );
 use XML::Parser;
 use IO::File;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -24,17 +24,17 @@ Data::Phrasebook::Loader::XML - Absract your phrases with XML.
 
   OR
 
-	my $q = Data::Phrasebook->new(
+    my $q = Data::Phrasebook->new(
         class  => 'Fnerk',
         loader => 'XML',
         file   => {
-			file => 'phrases.xml',
+            file => 'phrases.xml',
             ignore_whitespace => 1,
-	    }
+        }
     );
 
-   $q->delimiters( qr{ \[% \s* (\w+) \s* %\] }x );
-	my $phrase = $q->fetch($keyword);
+    $q->delimiters( qr{ \[% \s* (\w+) \s* %\] }x );
+    my $phrase = $q->fetch($keyword);
 
 =head1 ABSTRACT
 
@@ -237,25 +237,33 @@ __END__
 
 =head1 SEE ALSO
 
-L<Data::Phrasebook>
+L<Data::Phrasebook>.
+
+=head1 BUGS, PATCHES & FIXES
+
+There are no known bugs at the time of this release. However, if you spot a
+bug or are experiencing difficulties, that is not explained within the POD
+documentation, please send an email to barbie@cpan.org or submit a bug to the
+RT system (http://rt.cpan.org/). However, it would help greatly if you are 
+able to pinpoint problems or even supply a patch. 
+
+Fixes are dependant upon their severity and my availablity. Should a fix not
+be forthcoming, please feel free to (politely) remind me.
 
 =head1 AUTHOR
 
-Barbie, C< <<barbie@cpan.org>> >
-for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
+  Barbie, <barbie@cpan.org>
+  for Miss Barbell Productions <http://www.missbarbell.co.uk>.
 
-Birmingham Perl Mongers, L<http://birmingham.pm.org/>
+=head1 LICENCE AND COPYRIGHT
 
-=head1 COPYRIGHT AND LICENSE
+  Copyright (C) 2004-2005 Barbie for Miss Barbell Productions.
 
-  Copyright (C) 2004-2005 Barbie for Miss Barbell Productions
-  All Rights Reserved.
+  This library is free software; you can redistribute it and/or modify
+  it under the same terms as Perl itself.
 
-  This module is free software; you can redistribute it and/or 
-  modify it under the same terms as Perl itself.
-
-  The full text of the licences can be found in the F<Artistic> and
-  F<COPYING> files included with this module, or in L<perlartistic> and
-  L<perlgpl> in Perl 5.8.1 or later.
+The full text of the licences can be found in the F<Artistic> and
+F<COPYING> files included with this module, or in L<perlartistic> and
+L<perlgpl> in Perl 5.8.1 or later.
 
 =cut
